package com.ruixuan.isc.service.impl;


import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.kuaishou.merchant.open.api.KsMerchantApiException;
import com.kuaishou.merchant.open.api.client.AccessTokenKsMerchantClient;
import com.kuaishou.merchant.open.api.common.utils.GsonUtils;
import com.kuaishou.merchant.open.api.request.distribution.OpenDistributionInvestmentActivityInvalidItemListRequest;
import com.kuaishou.merchant.open.api.request.distribution.OpenDistributionInvestmentActivityItemDetailRequest;
import com.kuaishou.merchant.open.api.response.distribution.OpenDistributionInvestmentActivityInvalidItemListResponse;
import com.kuaishou.merchant.open.api.response.distribution.OpenDistributionInvestmentActivityItemDetailResponse;
import com.ruixuan.common.utils.Check;
import com.ruixuan.isc.constants.KuaiShouConstants;
import com.ruixuan.isc.entity.KuaishouItemList;
import com.ruixuan.isc.mapper.KuaishouItemListMapper;
import com.ruixuan.isc.service.IKuaishouItemListService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


/**
 * 【请填写功能名称】Service业务层处理
 *
 * @author ruoyi
 * @date 2023-02-03
 */
@Service
public class KuaishouItemListServiceImpl implements IKuaishouItemListService {
    @Autowired
    private KuaishouItemListMapper kuaishouItemListMapper;


    @Override
    public List<KuaishouItemList> getItemList(Map<String, Object> requestMap) {
        return kuaishouItemListMapper.getItemList(requestMap);
    }

    @Override
    public JSONObject getItemDetail(Long activityId, Long itemId, String accessToken) throws Exception {
        JSONObject returnJson = new JSONObject();
        AccessTokenKsMerchantClient client = new AccessTokenKsMerchantClient(KuaiShouConstants.KFX_URL, KuaiShouConstants.APP_KEY, KuaiShouConstants.SIGN_SECRET);
        OpenDistributionInvestmentActivityItemDetailRequest request = new OpenDistributionInvestmentActivityItemDetailRequest();
        request.setAccessToken(accessToken);
        request.setApiMethodVersion(1L);
        request.setActivityId(activityId);
        List<Long> item = new ArrayList<>();
        item.add(itemId);
        request.setItemId(item);
        OpenDistributionInvestmentActivityItemDetailResponse response = client.execute(request);
        JSONObject itemJson = JSONObject.parseObject(GsonUtils.toJSON(response));
        if (Check.isNull(itemJson)) {
            throw new Exception("获取商品信息出错，请重新提交");
        }
        Integer code = itemJson.getInteger("code");
        Integer subCode = itemJson.getInteger("sub_code");
        if (code == 1 && subCode == 1) {
            JSONArray data = itemJson.getJSONArray("data");
            if (Check.isNull(data)) {
                returnJson.put("code", -1);
                returnJson.put("message", "数据查询失败");
                return returnJson;
            }
            JSONObject itemJSon = data.getJSONObject(0);
            returnJson.put("judgeStatus", 1);
            returnJson.put("itemJSon", itemJSon);
            returnJson.put("code", 0);
            returnJson.put("message", "查询成功");
        } else if (code == 807000 && (subCode == 24101 || subCode == 24214)) { // 商品下线
            returnJson = getInvaliItemDetail(activityId, itemId, accessToken);
        } else {
            returnJson.put("code", -1);
            returnJson.put("message", "数据查询失败");
        }
        return returnJson;
    }

    @Override
    public KuaishouItemList getItemInfoByItemId(Long itemId) {
        return kuaishouItemListMapper.getItemInfoByItemId(itemId);
    }

    @Override
    public void insertItem(KuaishouItemList kuaishouItemList) {
        kuaishouItemListMapper.insertItem(kuaishouItemList);
    }

    @Override
    public int updateKuaishouItemList(KuaishouItemList kuaishouItemList) {
        return kuaishouItemListMapper.updateKuaishouItemList(kuaishouItemList);
    }

    @Override
    public int deleteKuaishouItemListByItemIds(Long[] itemIds) {
        return kuaishouItemListMapper.deleteKuaishouItemListByItemIds(itemIds);
    }


    private JSONObject getInvaliItemDetail(Long activityId, Long itemId, String accessToken) throws Exception {
        JSONObject returnJson = new JSONObject();
        AccessTokenKsMerchantClient client = new AccessTokenKsMerchantClient(KuaiShouConstants.KFX_URL, KuaiShouConstants.APP_KEY, KuaiShouConstants.SIGN_SECRET);
        OpenDistributionInvestmentActivityInvalidItemListRequest request = new OpenDistributionInvestmentActivityInvalidItemListRequest();
        request.setAccessToken(accessToken);
        request.setApiMethodVersion(1L);
        request.setOffset("0");
        request.setItemId(itemId);
        request.setActivityId(activityId);
        request.setLimit(10);
        request.setCloseType(0);
        OpenDistributionInvestmentActivityInvalidItemListResponse response = client.execute(request);
        JSONObject itemJson = JSONObject.parseObject(GsonUtils.toJSON(response));
        if (Check.isNull(itemJson)) {
            returnJson.put("code", -1);
            returnJson.put("message", "获取商品信息出错，请重新提交");
            return returnJson;
        }
        Integer code = itemJson.getInteger("code");
        Integer subCode = itemJson.getInteger("sub_code");

        if (code == 1 && subCode == 1) {
            JSONObject data = itemJson.getJSONObject("data");
            JSONArray array = data.getJSONArray("item");
            if (!Check.isNull(array)) {
                returnJson = array.getJSONObject(0);
                returnJson.put("judgeStatus", 2);
                returnJson.put("code", 0);
                returnJson.put("message", "查询成功");
            }

        } else {
            returnJson.put("code", 0);
            returnJson.put("message", "查询失败");
        }
        return returnJson;
    }

}

